"""
Command-line interface for the research agent
"""
import argparse
import asyncio
from pathlib import Path
from datetime import datetime
from .research_agent import RoseResearch

async def main():
    parser = argparse.ArgumentParser(description="Generate research papers")
    parser.add_argument("--topic", required=True, help="Research topic")
    parser.add_argument("--time-period", required=True, help="Time period to analyze")
    parser.add_argument("--output-dir", default="research_output", help="Output directory")
    args = parser.parse_args()
    
    # Create output directory
    output_dir = Path(args.output_dir)
    output_dir.mkdir(exist_ok=True)
    
    # Initialize research agent
    agent = RoseResearch()
    
    try:
        # Generate paper
        paper = await agent.generate_research_paper(args.topic, args.time_period)
        
        # Save paper
        timestamp = datetime.now().strftime("%Y%m%d_%H%M%S")
        output_file = output_dir / f"{args.topic.lower().replace(' ', '_')}_{timestamp}.pdf"
        
        with open(output_file, "wb") as f:
            f.write(paper["content"])
            
        print(f"Paper generated successfully: {output_file}")
        
    except Exception as e:
        print(f"Error generating paper: {e}")
        raise

if __name__ == "__main__":
    asyncio.run(main())
