from fastapi import FastAPI, HTTPException
from fastapi.responses import FileResponse
from fastapi.staticfiles import StaticFiles
from pathlib import Path
import uvicorn
import os

app = FastAPI(title="Research Paper Viewer")

# Mount static files directory
static_dir = Path(__file__).parent / "static"
static_dir.mkdir(exist_ok=True)
app.mount("/static", StaticFiles(directory=str(static_dir)), name="static")

@app.get("/")
async def root():
    return {"status": "online", "service": "Research Paper Viewer"}

@app.get("/papers/{paper_id}")
async def get_paper(paper_id: str):
    paper_path = static_dir / f"{paper_id}.pdf"
    if not paper_path.exists():
        raise HTTPException(status_code=404, detail="Paper not found")
    return FileResponse(str(paper_path))

def start_server():
    """Start the web interface server"""
    uvicorn.run(app, host="127.0.0.1", port=8000)

if __name__ == "__main__":
    start_server()
