"""Configuration module for the application."""

import json
import pandas as pd
import numpy as np
from datetime import datetime


class CustomJSONEncoder(json.JSONEncoder):
    """Custom JSON encoder for handling pandas and numpy types."""

    def default(self, obj):
        if isinstance(obj, pd.Timestamp):
            return obj.isoformat()
        if isinstance(obj, pd.DataFrame):
            return obj.to_dict(orient="records")
        if isinstance(obj, pd.Series):
            return obj.tolist()
        if isinstance(obj, np.ndarray):
            return obj.tolist()
        if isinstance(obj, datetime):
            return obj.isoformat()
        return super().default(obj)
