"""Market data caching module."""

from typing import Dict, Any
import pandas as pd
from datetime import datetime, timezone


class MarketCache:
    """Manages market data caching for efficient strategy execution."""

    def __init__(self):
        """Initialize the market data cache."""
        self.cache = {}

    def get_data(self, symbol: str, lookback: int = 100) -> pd.DataFrame:
        """Get market data for a symbol with specified lookback period."""
        # For testing purposes, return a mock DataFrame
        dates = pd.date_range(end=datetime.now(timezone.utc), periods=lookback)
        mock_data = pd.DataFrame(
            {
                "timestamp": dates,
                "open": [100] * lookback,
                "high": [105] * lookback,
                "low": [95] * lookback,
                "close": [102] * lookback,
                "volume": [1000] * lookback,
            }
        )
        mock_data.set_index("timestamp", inplace=True)
        return mock_data
