from fastapi import WebSocket
from typing import List, Dict, Any
import json


class WebSocketManager:
    def __init__(self):
        self.active_connections: List[WebSocket] = []

    async def connect(self, websocket: WebSocket):
        """Accept connection and add to active connections."""
        await websocket.accept()
        self.active_connections.append(websocket)

    async def disconnect(self, websocket: WebSocket):
        """Remove connection from active connections."""
        if websocket in self.active_connections:
            self.active_connections.remove(websocket)

    async def send_personal_message(
        self, message: Dict[str, Any], websocket: WebSocket
    ):
        """Send message to a specific client."""
        if isinstance(message, dict):
            message = json.dumps(message)
        await websocket.send_text(message)

    async def broadcast(self, message: Dict[str, Any]):
        """Broadcast message to all connected clients."""
        if isinstance(message, dict):
            message = json.dumps(message)
        for connection in self.active_connections:
            await connection.send_text(message)
