from fastapi import Request, HTTPException
from fastapi.middleware import Middleware
from fastapi.middleware.httpsredirect import HTTPSRedirectMiddleware

class SystemTokenValidation:
    def __init__(self, app):
        self.app = app
        self.valid_tokens = set()

    async def __call__(self, request: Request, call_next):
        if request.url.path.startswith("/sys/"):
            token = request.headers.get("x-system-token")
            if not token or token not in self.valid_tokens:
                raise HTTPException(status_code=403, detail="Invalid system token")
                
        response = await call_next(request)
        return response

def create_middleware_stack():
    return [
        Middleware(HTTPSRedirectMiddleware),
        Middleware(SystemTokenValidation)
    ]
