import time
from watchdog.observers.polling import PollingObserver
from watchdog.events import FileSystemEventHandler
import requests
from pathlib import Path

class ChangeHandler(FileSystemEventHandler):
    def __init__(self):
        self.api_url = "http://localhost:8000/api/v1/dev/notify-change"
        
    def _notify_change(self, event_type: str, path: str):
        if Path(path).suffix in ['.py', '.md', '.json', '.yaml', '.yml']:
            try:
                requests.post(
                    self.api_url,
                    params={"change_type": event_type, "file_path": path}
                )
            except:
                pass  # Silently fail if server isn't ready
                
    def on_modified(self, event):
        if not event.is_directory:
            self._notify_change("modified", event.src_path)
            
    def on_created(self, event):
        if not event.is_directory:
            self._notify_change("created", event.src_path)
            
    def on_deleted(self, event):
        if not event.is_directory:
            self._notify_change("deleted", event.src_path)

def start_watching():
    path = "."
    event_handler = ChangeHandler()
    observer = PollingObserver()
    observer.schedule(event_handler, path, recursive=True)
    observer.start()
    
    try:
        while True:
            time.sleep(1)
    except KeyboardInterrupt:
        observer.stop()
    observer.join()

if __name__ == "__main__":
    print("Starting file watcher...")
    start_watching()
